#
# spec file for package automake (Version 1.11.1)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           automake
BuildRequires:  bison help2man
License:        GPLv2+
Group:          Development/Tools/Building
AutoReqProv:    on
PreReq:         %{install_info_prereq}
Requires:       autoconf >= 2.62
Version:        1.11.1
Release:        6.5
Summary:        A Program for Automatically Generating GNU-Style Makefile.in Files
Url:            http://www.gnu.org/software/automake
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         automake-%{version}.tar.bz2
Source1:        automake-rpmlintrc
Patch1:         automake-SuSE.patch
Patch3:         automake-require_file.patch
BuildArch:      noarch

%description
Automake is a tool for automatically generating "Makefile.in" files
from "Makefile.am" files.  "Makefile.am" is a series of "make" macro
definitions (with rules occasionally thrown in).  The generated
"Makefile.in" files are compatible with the GNU Makefile standards.



Authors:
--------
    David Mackenzie
    Tom Tromey  <tromey@cygnus.com>
    Alexandre Oliva
    Alexandre Duret-Lutz <adl@gnu.org>

%prep
%setup -q -n automake-%{version}
%patch1
%patch3

%build
%configure --docdir=%{_docdir}/%{name}
make %{?_smp_mflags};
%if "%{name}" == "automake-testsuite"

%check
# Some architectures can't keep up the pace.
%ifnarch alpha %arm
make check VERBOSE=1
%endif

%install
%else

%install
%makeinstall
mkdir -p %{buildroot}/etc %{buildroot}/usr/share/aclocal
echo /usr/local/share/aclocal >%{buildroot}/etc/aclocal_dirlist
ln -s ../../../etc/aclocal_dirlist %{buildroot}/usr/share/aclocal/dirlist
mkdir -p %{buildroot}%{_mandir}/man1
perllibdir=lib help2man -S FSF ./aclocal > %{buildroot}%{_mandir}/man1/aclocal.1
perllibdir=lib help2man -S FSF ./automake > %{buildroot}%{_mandir}/man1/automake.1
install -m644 AUTHORS COPYING ChangeLog NEWS README THANKS %{buildroot}%{_docdir}/%{name}
#name == automake
%endif

%post
%install_info --info-dir=%{_infodir} %{_infodir}/automake.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/automake.info.gz

%clean
rm -rf %{buildroot}
%if "%{name}" == "automake"

%files
%defattr(-,root,root)
%doc %{_docdir}/%{name}
%{_bindir}/*
%doc %{_infodir}/*.gz
%doc %{_mandir}/man1/*
%{_datadir}/aclocal*
%{_datadir}/automake-*
%config /etc/aclocal_dirlist
%endif

%changelog
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Fri Dec 11 2009 pth@suse.de
- Update to 1.11.1 (bnc#559815):
  - The `parallel-tests' test driver works around a GNU make 3.80
    bug with trailing white space in the test list
    (`TESTS = foo $(EMPTY)').
  * Long standing bugs:
  - The testsuite does not try to change the mode of `ltmain.sh'
    files from a Libtool installation (symlinked to test
    directories) any more.
  - AM_PROG_GCJ uses AC_CHECK_TOOLS to look for `gcj' now, so
    that prefixed tools are preferred in a cross-compile setup.
  - The distribution is tarred up with mode 755 now by the
    `dist*' targets.  This fixes a race condition where untrusted
    users could modify files in the $(PACKAGE)-$(VERSION) distdir
    before packing if the toplevel build directory was
    world-searchable.  This is CVE-2009-4029.
- Make automake a noarch package.
  Sun Dec  6 18:02:39 CET 2009 - jengelh
- enable parallel building
* Wed Aug 26 2009 coolo@novell.com
- rediff to avoid fuzz
* Fri Jul 10 2009 jansimon.moeller@opensuse.org
- Disable the testsuite also for ARM as it blocks/stalls the worker.
* Sun Jun 21 2009 coolo@novell.com
- add empty %%install section to testsuite to fix build
* Tue Jun 16 2009 coolo@novell.com
- split test suit into own package (new policy for bootstrap)
* Fri May 29 2009 puzel@suse.cz
- update to automake-1.11
  - noteworthy changes:
  - require autoconf-2.62
  - The autoconf version check implemented by aclocal in aclocal.m4
    (and new in Automake 1.10) is degraded to a warning.  This helps
  - The automake program can run multiple threads for creating most
  Makefile.in files concurrently in the common case where the Autoconf
  versions used are compatible.
  - Libtool generic flags are now passed to the install and uninstall
    modes as well.
  - distcheck works with Libtool 2.x even when LT_OUTPUT is used, as
    config.lt is removed correctly now.
  - subdir-object mode works now with Fortran (F77, FC, preprocessed
    Fortran, and Ratfor).
  - For files with extension .f90, .f95, .f03, or .f08, the flag
  $(FCFLAGS_f[09]x) computed by AC_FC_SRCEXT is now used in compile rules.
  - Files with extension .sx are also treated as preprocessed assembler.
  - The default source file extension (.c) can be overridden with
    AM_DEFAULT_SOURCE_EXT now.
  - Python 3.0 is supported now, Python releases prior to 2.0 are no
    longer supported.
  - AM_PATH_PYTHON honors python's idea about the site directory.
  - "make dist" can now create xz-compressed tarballs,
    as well as (deprecated?) lzma-compressed tarballs.
  - `automake --add-missing' will by default install the GPLv3 file as
    COPYING if it is missing.
  - for full changelog please see /usr/share/doc/packages/automake/NEWS
- remove automake-fix_check10.patch (fixed upstream)
- add automake-11.1-skip-specflg10-without-g++.patch (from upstream git)
* Thu Apr 30 2009 pth@suse.de
- Add upstream post 1.10.2 patch to fix the failing check10.test.
* Wed Apr 29 2009 pth@suse.de
- Rediff to sync the patches (automake-require_file.patch was off
  by ~ 500 lines). Update the reference to bugzilla for this patch.
* Wed Mar 11 2009 pth@suse.de
- Update to 1.10.2:
  * Rebuild rules now also work for a removed `subdir/Makefile.in' in
    an otherwise up to date tree.
  * Work around AIX sh quoting issue in AC_PROG_CC_C_O, leading to
    unnecessary use of the `compile' script.
  * `config.status --file=Makefile depfiles' now also works with the
    extra quoting used internally by Autoconf 2.62 and newer
    (it used to work only without the `--file=' bit).
  * distcheck works with Libtool 2.x even when LT_OUTPUT is used, as
    config.lt is removed correctly now.
  * The manual is now distributed under the terms of the GNU FDL 1.3.
  * When `automake --add-missing' causes the COPYING file to be installed,
    it will also warn that the license file should be added to source
    control.
- Add bison again.
- Pass docdir on to configure.
- Add a rpmlintrc file
* Wed Mar  4 2009 pth@suse.de
- Prefix patches with package name.
* Mon Jan 28 2008 schwab@suse.de
- Revert last change.
* Sat Jan 26 2008 aj@suse.de
- Add bison as buildrequirs for the testsuite.
* Tue Jan 22 2008 schwab@suse.de
- Update to automake 1.10.1.
  * Automake development is done in a git repository on Savannah now, see
    http://git.sv.gnu.org/gitweb/?p=automake.git
    A read-only CVS mirror is provided at
    cvs -d :pserver:anonymous@pserver.git.sv.gnu.org:/automake.git \
    checkout -d automake HEAD
  * "make dist" can now create lzma-compressed tarballs.
  * `automake --add-missing' will by default install the GPLv3 file as
    COPYING if it is missing.  Note that Automake will never overwrite
    an existing COPYING file, even when the `--force-missing' option is
    used.  Further note that Automake 1.10.1 is still licensed under GPLv2+.
  * Libtool generic flags are now passed to the install and uninstall
    modes as well.
  * Files with extension .sx are also treated as preprocessed assembler.
  * install-sh now has an BSD-like option `-C' to preserve modification
    times of unchanged files upon installation.
  * Fix aix dependency tracking for libtool objects.
  * The signal handling of aclocal has been improved.
  * Targets beginning with a digit are now recognized correctly.
  * All directories `.libs'/`_libs' used by libtool are cleaned now,
    not only those in which libraries are built.
  * Fix output of dummy dependency files in presence of post-processed
    Makefile.in's again, but also cope with long lines.
  * $(EXEEXT) is automatically appended to filenames of XFAIL_TESTS
    that have been declared as programs in the same Makefile.
    This is for consistency with the analogous change to TESTS in 1.10.
  * The autoconf version check implemented by aclocal in aclocal.m4
    (and new in Automake 1.10) is degraded to a warning.  This helps
    in the common case where the Autoconf versions used are compatible.
  * Fix order of standard includes to again be `-I. -I$(srcdir)',
    followed by directories containing config headers.
* Fri Nov 23 2007 schwab@suse.de
- Fix last change.
* Mon Nov 12 2007 dmueller@suse.de
- require the autoconf version it was build against
* Thu Oct 11 2007 schwab@suse.de
- Add lzma support.
* Mon Jan 29 2007 sbrabec@suse.cz
- Removed references to /opt/gnome.
* Sun Oct 15 2006 schwab@suse.de
- Update to automake 1.10.
  * Version requirements:
  - Autoconf 2.60 or greater is required.
  - Perl 5.6 or greater is required.
  * Changes to aclocal:
  - aclocal now also supports -Wmumble and -Wno-mumble options.
  - `dirlist' entries (for the aclocal search path) may use shell
    wildcards such as `*', `?', or `[...]'.
  - aclocal supports an --install option that will cause system-wide
    third-party macros to be installed in the local directory
    specified with the first -I flag.  This option also uses #serial
    lines in M4 files to upgrade local macros.
    The new aclocal options --dry-run and --diff help to review changes
    before they are installed.
  - aclocal now outputs an autoconf version check in aclocal.m4 in
    projects using automake.
    For a few years, automake and aclocal have been calling autoconf
    (or its underlying engine autom4te) to accurately retrieve the
    data they need from configure.ac and its siblings.  Doing so can
    only work if all autotools use the same version of autoconf.  For
    instance a Makefile.in generated by automake for one version of
    autoconf may stop working if configure is regenerated with another
    version of autoconf, and vice versa.
    This new version check ensures that the whole build system has
    been generated using the same autoconf version.
  * Support for new Autoconf macros:
  - The new AC_REQUIRE_AUX_FILE Autoconf macro is supported.
  - If `subdir-objects' is set, and AC_CONFIG_LIBOBJ_DIR is specified,
    $(LIBOBJS), $(LTLIBOBJS), $(ALLOCA), and $(LTALLOCA) can be used
    in different directories.  However, only one instance of such a
    library objects directory is supported.
  * Change to Libtool support:
  - Libtool generic flags (those that go before the --mode=MODE option)
    can be specified using AM_LIBTOOLFLAGS and target_LIBTOOLFLAGS.
  * Yacc and Lex changes:
  - The rebuild rules for distributed Yacc and Lex output will avoid
    overwriting existing files if AM_MAINTAINER_MODE and maintainer-mode
    is not enabled.
  - ylwrap is now always used for lex and yacc source files,
    regardless of whether there is more than one source per directory.
  * Languages changes:
  - Preprocessed assembler (*.S) compilation now honors CPPFLAGS,
    AM_CPPFLAGS and per-target _CPPFLAGS, and supports dependency
    tracking, unlike non-preprocessed assembler (*.s).
  - subdir-object mode works now with Assembler.  Automake assumes
    that the compiler understands `-c -o'.
  - Preprocessed assembler (*.S) compilation now also honors
    $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES).
  - Improved support for Objective C:
  - Autoconf's new AC_PROG_OBJC will enable automatic dependency tracking.
  - A new section of the manual documents the support.
  - New support for Unified Parallel C:
  - AM_PROG_UPC looks for a UPC compiler.
  - A new section of the manual documents the support.
  - Per-target flags are now correctly handled in link rules.
    For instance maude_CFLAGS correctly overrides AM_CFLAGS; likewise
    for maude_LDFLAGS and AM_LDFLAGS.  Previous versions bogusly
    preferred AM_CFLAGS over maude_CFLAGS while linking, and they
    used both AM_LDFLAGS and maude_LDFLAGS on the same link command.
    The fix for compiler flags (i.e., using maude_CFLAGS instead of
    AM_CFLAGS) should not hurt any package since that is how _CFLAGS
    is expected to work (and actually works during compilation).
    However using maude_LDFLAGS "instead of" AM_LDFLAGS rather than
    "in addition to" breaks backward compatibility with older versions.
    If your package used both variables, as in
  AM_LDFLAGS = common flags
  bin_PROGRAMS = a b c
  a_LDFLAGS = more flags
  ...
    and assumed *_LDFLAGS would sum up, you should rewrite it as
  AM_LDFLAGS = common flags
  bin_PROGRAMS = a b c
  a_LDFLAGS = $(AM_LDFLAGS) more flags
  ...
    This new behavior of *_LDFLAGS is more coherent with other
    per-target variables, and the way *_LDFLAGS variables were
    considered internally.
  * New installation targets:
  - New targets mandated by GNU Coding Standards:
  install-dvi
  install-html
  install-ps
  install-pdf
    By default they will only install Texinfo manuals.
    You can customize them with *-local variants:
  install-dvi-local
  install-html-local
  install-ps-local
  install-pdf-local
  - The undocumented recursive target `uninstall-info' no longer exists.
    (`uninstall' is in charge of removing all possible documentation
    flavors, including optional formats such as dvi, ps, or info even
    when `no-installinfo' is used.)
  * Miscellaneous changes:
  - Automake no longer complains if input files for AC_CONFIG_FILES
    are specified using shell variables.
  - clean, distribution, or rebuild rules are normally disabled for
    inputs and outputs of AC_CONFIG_FILES, AC_CONFIG_HEADERS, and
    AC_CONFIG_LINK specified using shell variables.  However, if these
    variables are used as ${VAR}, and AC_SUBSTed, then Automake will
    be able to output rules anyway.
    (See the Automake documentation for AC_CONFIG_FILES.)
  - $(EXEEXT) is automatically appended to filenames of TESTS
    that have been declared as programs in the same Makefile.
    This is mostly useful when some check_PROGRAMS are listed in TESTS.
  - `-Wportability' has finally been turned on by default for `gnu' and
    `gnits' strictness.  This means, automake will complain about %%-rules
    or $(GNU Make functions) unless you switch to `foreign' strictness or
    use `-Wno-portability'.
  - Automake now uses AC_PROG_MKDIR_P (new in Autoconf 2.60), and uses
    $(MKDIR_P) instead of $(mkdir_p) to create directories.  The
    $(mkdir_p) variable is still defined (to the same value as
    $(MKDIR_P)) but should be considered obsolete.  If you are using
    $(mkdir_p) in some of your rules, please plan to update them to
    $(MKDIR_P) at some point.
  - AM_C_PROTOTYPES and ansi2knr are now documented as being obsolete.
    They still work in this release, but may be withdrawn in a future one.
  - Inline compilation rules for gcc3-style dependency tracking are
    more readable.
  - Automake installs a "Hello World!" example package in $(docdir).
    This example is used throughout the new "Autotools Introduction"
    chapter of the manual.
* Mon Aug 21 2006 sbrabec@suse.cz
- Removed dirlist.d support, use hardwired path instead.
* Mon Jul 31 2006 schwab@suse.de
- Remove obsolete patch.
* Mon May 15 2006 schwab@suse.de
- Import latest versions of config.{guess,sub}.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jul 11 2005 schwab@suse.de
- Update to automake 1.9.6.
* Sun May  8 2005 schwab@suse.de
- Some architectures can't keep up the pace.
* Sat May  7 2005 matz@suse.de
- Split away an automake-check package, which does the make check.
* Sun Feb 13 2005 schwab@suse.de
- Update to automake 1.9.5.
* Fri Jan 14 2005 schwab@suse.de
- Fix require_file_internal to handle file names with directories
  (bnc#64822).
* Wed Jan 12 2005 schwab@suse.de
- Update to automake 1.9.4.
* Thu Nov 25 2004 ro@suse.de
- incremental fix for py-compile
* Fri Nov 19 2004 schwab@suse.de
- Fix py-compile to avoid putting $(DESTDIR) in the output.
* Mon Nov  1 2004 schwab@suse.de
- Update to automake 1.9.3.
* Fri Oct  8 2004 schwab@suse.de
- Update to automake 1.9.2.
* Mon Aug 30 2004 schwab@suse.de
- Fix $PATH_PATTERN.
* Tue Aug 17 2004 schwab@suse.de
- Fix handling of subdir-objects.
* Thu Aug 12 2004 schwab@suse.de
- Update to automake 1.9.1.
* Thu Jul 29 2004 schwab@suse.de
- Update to automake 1.9.
* Mon Jul 19 2004 schwab@suse.de
- Fix quoting.
* Sat Jul 17 2004 schwab@suse.de
- Update to automake 1.8d (1.9 release candidate).
* Mon May 17 2004 schwab@suse.de
- Update to automake 1.8.5.
* Tue May  4 2004 schwab@suse.de
- Update to automake 1.8.4.
* Sun Mar  7 2004 schwab@suse.de
- Update to automake 1.8.3.
* Sat Jan 17 2004 schwab@suse.de
- Fix race condition in testsuite.
* Tue Jan 13 2004 schwab@suse.de
- Update to automake 1.8.2.
* Mon Jan 12 2004 schwab@suse.de
- Update to automake 1.8.1.
* Thu Jan  8 2004 schwab@suse.de
- Fix use of undefined value.
* Thu Dec 11 2003 schwab@suse.de
- Update to automake 1.8.
* Mon Nov 10 2003 schwab@suse.de
- Update to automake 1.7.9.
* Tue Oct  7 2003 schwab@suse.de
- Update to automake 1.7.8.
* Mon Sep  8 2003 schwab@suse.de
- Update to automake 1.7.7.
* Wed Jul 16 2003 sbrabec@suse.cz
- Added support for /usr/share/aclocal/dirlist.
* Fri Jul 11 2003 schwab@suse.de
- Update to automake 1.7.6.
* Tue Jun 10 2003 schwab@suse.de
- Update to automake 1.7.5.
* Mon May 12 2003 schwab@suse.de
- Add %%defattr.
* Fri Apr 25 2003 schwab@suse.de
- Update to automake 1.7.3.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Mon Jan 20 2003 schwab@suse.de
- Fix python macros properly.
* Fri Dec  6 2002 schwab@suse.de
- Update to automake 1.7.2.
  * Many bug fixes.
* Thu Nov 21 2002 schwab@suse.de
- Fix ansi2knr option.
* Mon Nov 18 2002 ro@suse.de
- use /.buildenv like /etc/SuSE-release
* Fri Sep 27 2002 schwab@suse.de
- Update to automake 1.7.
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Aug  5 2002 schwab@suse.de
- Update to automake 1.6.3.
  * Support for AM_INIT_GETTEXT([external])
  * Bug fixes
* Thu Jun 20 2002 schwab@suse.de
- Fix python macros for lib64.
* Sat Jun 15 2002 schwab@suse.de
- Update to automake 1.6.2.
  * Bug fix release.
* Fri Apr 12 2002 schwab@suse.de
- Update to automake 1.6.1.
* Fri Mar 29 2002 schwab@suse.de
- Fix typo check.
- Disable libtool vs. normal check.
- Make dependency generation work with KDE.
* Mon Mar 11 2002 schwab@suse.de
- Add versioned links to automake and aclocal.
* Thu Mar  7 2002 schwab@suse.de
- Update to automake 1.6.
* Wed Jan 23 2002 schwab@suse.de
- Fix nonportable test option in config.guess.
* Sun Dec 16 2001 adrian@suse.de
- fix config.guess to recognize SGI mips systems as big endian systems
- bzip2 sources
* Mon Aug 27 2001 schwab@suse.de
- Update to automake 1.5.
* Thu Aug  9 2001 ro@suse.de
- fixed problem when installing lisp files
* Thu Jul 19 2001 schwab@suse.de
- Update to automake 1.4-p5.
* Tue Jun 12 2001 olh@suse.de
- recognize ppc64
* Tue Jun 12 2001 olh@suse.de
- fix typo in automake-1.4-SuSE.patch
* Mon Jun 11 2001 schwab@suse.de
- Recognize AC_PROG_LIBTOOL as well as AM_PROG_LIBTOOL.
* Mon Jun 11 2001 schwab@suse.de
- Update to automake 1.4-p4.
* Sat May 26 2001 schwab@suse.de
- Update to automake 1.4-p2.
* Wed May  9 2001 schwab@suse.de
- Update to automake 1.4-p1.
* Fri May  4 2001 schwab@suse.de
- Fix automake script for libtool 1.4.
* Fri Mar 30 2001 schwab@suse.de
- config.sub: don't try to fill missing parts by looking at the host
  system.
* Thu Feb 15 2001 schwab@suse.de
- Update config.{guess,sub} to latest version.
* Wed Sep 13 2000 schwab@suse.de
- Add bzip2 patch from kkaempf@suse.de.
* Mon Aug 21 2000 werner@suse.de
- Use vendor within config.sub even for s390
* Mon May  1 2000 kukuk@suse.de
- Use mandir und infodir macro
* Wed Mar 29 2000 bk@suse.de
- updated config.guess and config.sub for s390
* Wed Mar  1 2000 werner@suse.de
- Add arm/ppc patch from teTeX sources
- Make VENDOR=suse if /etc/SuSE-release exists, remove `-gnu', and
  use $VERNDOR for all Linux architectures.
* Tue Feb 15 2000 schwab@suse.de
- Update config.{guess,sub} to latest version.
* Thu Jan 20 2000 kukuk@suse.de
- Move /usr/{info,man} -> /usr/share/{info,man}
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Aug 26 1999 kukuk@suse.de
- Add automake.1, aclocal.1 and other documentation
- Add make check to build section
* Fri Feb 26 1999 florian@suse.de
- update to 1.4
* Fri Jun 19 1998 ro@suse.de
- update to 1.3 using dif from jurix
* Wed Jun 25 1997 florian@suse.de
- update to version 1.2
* Thu Jan  2 1997 florian@suse.de
  new version 1.0
